#define BPF_NO_GLOBAL_DATA
#include <stdio.h>
#include <unistd.h>
#include "ic.h"

int main(int argc, char *argv[], char *argp[]){
    printf("Hello world\n");
    char buf[300];

    ic_influx_database("192.168.1.68", 8086, "tcp");
    ic_influx_userpw("admin", "Geta,Fte#");
    ic_debug(2);

    snprintf(buf, 300, "host=192.168.1.68");
    ic_tags(buf);

    ic_measure("tcp_reset");

    ic_string("ipsrc", "192.168.1.1");

    ic_measureend();
    ic_push();

    return 0;
}
